<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../../../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Gruppeindstillinger</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Gruppenavn:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>Gruppe-ID:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Brugere tilhører denne gruppe:</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../../../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Gruppenavnet må ikke være tomt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Bruger- og gruppeindstillinger</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Brugere</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Login-navn</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>Bruger-ID</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Fulde navn</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Hjemmemappe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Vis systemets brugere (kun for avancerede brugere)</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Grupper</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>Gruppe-ID</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Medlemmer</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="134"/>
        <source>toolBar</source>
        <translation>Værktøjslinje</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="161"/>
        <source>Add</source>
        <translation>Tilføj</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="164"/>
        <source>Add new users or groups</source>
        <translation>Tilføj nye brugere eller grupper</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="173"/>
        <source>Delete</source>
        <translation>Slet</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="176"/>
        <source>Delete selected item</source>
        <translation>Slet valgte post</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="185"/>
        <source>Properties</source>
        <translation>Egenskaber</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="188"/>
        <source>edit properties of the selected item</source>
        <translation>rediger egenskaber for den valgte post</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="197"/>
        <source>Refresh</source>
        <translation>Opdater</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="200"/>
        <source>Refresh the lists</source>
        <translation>Opdater listerne</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="209"/>
        <source>Change Password</source>
        <translation>Skift adgangskode</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.ui" line="212"/>
        <source>Change password for the selected user or group</source>
        <translation>Skift adgangskode for den valgte bruger eller gruppe</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="174"/>
        <location filename="../../../mainwindow.cpp" line="186"/>
        <location filename="../../../mainwindow.cpp" line="207"/>
        <source>Confirm</source>
        <translation>Bekræft</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="174"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Er du sikker på, at du vil slette den valgte bruger?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="186"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Er du sikker på, at du vil slette den valgte gruppe?</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="197"/>
        <source>Input the new password for %1:</source>
        <translation>Input den nye adgangskode til %1:</translation>
    </message>
    <message>
        <location filename="../../../mainwindow.cpp" line="207"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Er du sikker på, at du vil sætte en tom adgangskode?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../../../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Brugerindstillinger</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Fulde navn:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Login-navn:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>Bruger-ID:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Hovedgruppe:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Grupper</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>Brugeren tilhører følgende grupper:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Avanceret</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Login-skal:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Hjemmemappe:</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../../../userdialog.cpp" line="117"/>
        <source>The user name cannot be empty.</source>
        <translation>Brugernavnet må ikke være tomt.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../../../usermanager.cpp" line="224"/>
        <source>lxqt-admin-user</source>
        <translation>lxqt-admin-user</translation>
    </message>
    <message>
        <location filename="../../../usermanager.cpp" line="225"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;Handling (%1) mislykkedes:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>
